==> haskell-what4-1.6-35-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-Fx3516WUxAIJcsiFr2IKtg
key:                  what4-1.6-Fx3516WUxAIJcsiFr2IKtg
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  7c2c3387ac762089b4f248f397a134bb
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-Fx3516WUxAIJcsiFr2IKtg
depends:
    BoundedChan-1.0.3.0-LpypBc0eid95svZdMy7DB6
    async-2.2.5-DWviBtrYTc7K8qRxzPsJC
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    bifunctors-5.6.2-55pB15N2vUAu5vVW3jWWD
    bimap-0.5.0-77iEKcWjxXFFUam8W2G4x7
    bv-sized-1.0.6-BhUc4hNjR4RAGJ0MU8zxHJ bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-ZZmsVr0E6Z2lV7NnUUK3y
    config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH containers-0.6.7
    deepseq-1.4.8.0 deriving-compat-0.6.7-GHxeBnYKQZ34k6iiHHrUYz
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    fingertree-0.1.6.2-HyFF8R8DbBb1f3TaBV8sAi ghc-prim-0.9.1
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    hashtables-1.4.1-9uT6vyDoHIH4k1a5Jg8ktz
    io-streams-1.5.2.2-HTsZjq0uxoOIVNehfMFaNS
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    libBF-0.6.6-DnxZz25o7My9xEqumGMTLr
    megaparsec-9.7.0-8vxoLKsvFvg2EeYv7J5Buq mtl-2.2.2
    ordered-containers-0.2.4-87ddwGMP3stCAKmedQHsrU
    panic-0.4.0.1-Jq9VAg5hh1m6c8kWsB4pox
    parameterized-utils-2.1.10.0-7LSyxSOd93DLAJtjTt6RNS parsec-3.1.16.1
    prettyprinter-1.7.1-18Jm3UFnGYW2Ifx2izjEAg process-1.6.18.0
    s-cargot-0.1.6.0-CDsx52woaP53dEnvg4vRik
    scientific-0.3.8.0-L88GQ4rEhQfGc3NVSCAVTu stm-2.5.1.0
    template-haskell-2.19.0.0 temporary-1.3-9l44ZQzJSbTL0MfCqPU8eB
    text-2.0.2 th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    th-lift-instances-0.1.20-4HlXS6eUQvv3LpmmJLLB0s time-1.12.2
    transformers-0.5.6.2 unliftio-0.2.25.1-83PwQVOhURl3H5nxoMcX3o
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57
    versions-6.0.8-6ftRug6VP5CBiw5Skck9b2
    zenc-0.1.2-Li2ZuVV5eiSGCRudo51zgB

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-what4-1.6-57-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-what4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-IUEuV5oA2SCEkZcKfVLpq4
key:                  what4-1.6-IUEuV5oA2SCEkZcKfVLpq4
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  cffd6a5c84aa78aae4410435d33b57a6
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-IUEuV5oA2SCEkZcKfVLpq4
depends:
    BoundedChan-1.0.3.0-LpypBc0eid95svZdMy7DB6
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    bifunctors-5.6.2-qYz8iRzlWuJF3JayYfzK3
    bimap-0.5.0-KuDXubjXrX3bQhqKAD8DF
    bv-sized-1.0.6-5oEul6zt1G3JA0wtjT5LK bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-1biGfrYffDc12InnqXEPIT
    config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH containers-0.6.7
    deepseq-1.4.8.0 deriving-compat-0.6.7-ga9Y1AT4waKCNhHKSm9gZ
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    fingertree-0.1.6.2-9t49hsSqDY3BaiXjhf8y3o ghc-prim-0.9.1
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    hashtables-1.4.2-8Y2pIuBEj2Y7gBUSR30eie
    io-streams-1.5.2.2-CqhNECtx3ZHFkLKvc41w22
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    libBF-0.6.6-EikARrx3HOzI3GJqje3fxy
    megaparsec-9.7.0-A5HZG6HxQB028mYZSYROei mtl-2.2.2
    ordered-containers-0.2.4-26t27C07bEPADHnhUohNXA
    panic-0.4.0.1-3QvhbYIlGoL4pBeY3qhGHr
    parameterized-utils-2.1.10.0-GzuSb1xDXv4DyqINT4dPm9 parsec-3.1.16.1
    prettyprinter-1.7.1-IxfK3MMc5TsGC7SkX421m7 process-1.6.18.0
    s-cargot-0.1.6.0-EsQurOoGpzPHNiHKiKTQg6
    scientific-0.3.8.0-6QoqQGQc0yZ1FsULZsdy9C stm-2.5.1.0
    template-haskell-2.19.0.0 temporary-1.3-Kn2M9G1H4VS6orEei4BtCV
    text-2.0.2 th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    th-lift-instances-0.1.20-HSRjlGXAGtLJZoUMZdls5z time-1.12.2
    transformers-0.5.6.2 unliftio-0.2.25.1-jUDvU4O8PS8SoQvWmG5yt
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    versions-6.0.8-KRV5Dk0sCefBU3FIg20eCr
    zenc-0.1.2-9E2kNMfgU7rEcf5Ui7pxdl

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
